<?php

namespace App\Http\Controllers;

use App\domain\travelport\ticketing\AddFormOfPaymentAction;
use App\domain\travelport\ticketing\AddPaymentAction;
use App\domain\travelport\ticketing\CommitReservationTicketIssuanceAction;
use App\domain\travelport\ticketing\CreateTicketAction;
use App\domain\travelport\ticketing\PostCommitInitiateWorkbenchAction;
use App\domain\travelport\ticketing\PreTicketReviewAction;
use Exception;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Log;

class TicketWorkbenchController extends Controller
{
    public function createTicket(Request $request,CreateTicketAction $action): JsonResponse
    {
        try {
            $response = $action->execute(
                reservationId: $request->input('reservationId'),
                payType: $request->input('payType'),
                currencyCode: $request->input('currencyCode'),
                amount: $request->input('amount'),
            );

            return response()->json($response, Response::HTTP_OK);
        } catch (Exception $e) {
            Log::error("postCommitInitiate: " . $e->getMessage());
            return response()->json([
                'error_message' => $e->getMessage(),
            ], Response::HTTP_BAD_REQUEST);
        }
    }
    public function postCommitInitiate(Request $request, PostCommitInitiateWorkbenchAction $action): JsonResponse
    {
        try {
            return response()->json($action->execute($request->input('locatorId')), Response::HTTP_OK);
        } catch (\Exception $e) {
            Log::error("postCommitInitiate: " . $e->getMessage());
            return response()->json([
                'error_message' => $e->getMessage(),
            ], Response::HTTP_BAD_REQUEST);
        }
    }

    public function addFormOfPayment(Request $request, AddFormOfPaymentAction $action): JsonResponse
    {
        try {
            return response()->json(
                $action->execute($request->input('ticketWorkbenchAuthorityValue')),
                Response::HTTP_OK
            );
        } catch (Exception $e) {
            Log::error("addFormOfPayment: " . $e->getMessage());
            return response()->json([
                'error_message' => $e->getMessage(),
            ], Response::HTTP_BAD_REQUEST);
        }
    }

    public function addPayment(Request $request, AddPaymentAction $action): JsonResponse
    {
        try {
            $response = $action->execute(
                $request->input('ticketWorkbenchAuthorityValue'),
                $request->input('payType'),
                $request->input('currencyCode'),
                $request->input('amount'),
                $request->input('formOfPaymentIdentifier'),
                $request->input('offerIdentifier'),
            );
            return response()->json(
                $response,
                Response::HTTP_OK
            );
        } catch (Exception $e) {
            Log::error("addPaymentCash: " . $e->getMessage());
            return response()->json([
                'error_message' => $e->getMessage(),
            ], Response::HTTP_BAD_REQUEST);
        }
    }

    public function preTicketReview(Request $request,PreTicketReviewAction $action): JsonResponse
    {
        try {
            return response()->json(
                $action->execute($request->input('ticketWorkbenchAuthorityValue')),
                Response::HTTP_OK
            );
        } catch (Exception $e) {
            Log::error("addFormOfPayment: " . $e->getMessage());
            return response()->json([
                'error_message' => $e->getMessage(),
            ], Response::HTTP_BAD_REQUEST);
        }
    }

    public function commitReservationTicketIssuance(Request $request,CommitReservationTicketIssuanceAction $action): JsonResponse
    {
        try {
            return response()->json(
                $action->execute($request->input('ticketWorkbenchAuthorityValue')),
                Response::HTTP_OK
            );
        } catch (Exception $e) {
            Log::error("addFormOfPayment: " . $e->getMessage());
            return response()->json([
                'error_message' => $e->getMessage(),
            ], Response::HTTP_BAD_REQUEST);
        }
    }
}
